@@ -4,6 +4,7 @@ from pythonagent.lib import get_ident
 import ctypes
 import os
 
+
 from pythonagent.agent.probes.havoc.havoc_manager import NDNetHavocMonitor, NDHavocException
 
 from pythonagent.agent.internal import udp
@@ -12,6 +13,7 @@ from pythonagent.agent.probes.Instrumentation.find import find
 
 
 
+
 class TransactionContext(object):
     def __init__(self):
         self.nd_init_done = None
@@ -195,7 +197,7 @@ class Agent(object):
         return self.lib
 
     def ai_wrapper_begin_native(self):
-        print("************************ callback registered ********************************************")
+        self.logger.info("************************ callback registered ********************************************")
         self.lib.register_AI_start_callback(self.c_startaisession)
 
     def ai_wrapper_begin(self):
@@ -214,11 +216,11 @@ class Agent(object):
             udp.ai_wrapper_end()
 
     def endaisessioncc(self, char):
-        print("INSIDE END AI SESSION")
+        self.logger.info("INSIDE END AI SESSION")
 
     def startaisession(self, istart, startTime, duration, sname):
-        print("session status \n", istart)
-        print(" IN startaisession", sname.decode('ascii'))
+        self.logger.info("session status \n", istart)
+        self.logger.info(" IN startaisession", sname.decode('ascii'))
         wsgi.aiflagset(istart, startTime, duration, sname)
         pathd = "/opt/cavisson/netdiagnostics/logs/"
         filenameai1 = str(self.sess.decode('ascii')) + ".txt"
@@ -234,7 +236,7 @@ class Agent(object):
 
 
     def thd(self):
-        print("INSIDE THD")
+        self.logger.info("INSIDE THD")
         # dumpstacks()
 
     def thd_funct(self, a, b, c, d):
@@ -264,7 +266,7 @@ class Agent(object):
 
     # @profile
     def method_entry_native(self, bt, method):
-        print('Inside method entry ', method, bt)
+        self.logger.info('Inside method entry {} {}'.format( method, bt))
         self.logger.info("method entry -> lib.obj :{0}".format(self.lib))
         self.logger.info("method entry -> method name :{0}".format(method))
         # defer C.free(unsafe.Pointer(method_c))
@@ -293,7 +295,7 @@ class Agent(object):
 
     #@profile
     def method_exit_native(self, bt, method):
-            print('in method exit', method, bt)
+            self.logger.info('in method exit {} {}'.format(method, bt))
             self.logger.info("load common lib -> lib.obj :{0}".format(self.lib))
             self.logger.info("method entry -> method name :{0}".format(method))
             # defer C.free(unsafe.Pointer(method_c))
@@ -302,7 +304,7 @@ class Agent(object):
                 method_bytes = bytes(method, 'utf-8')
             except:
                 method_bytes = bytes(method.encode("utf-8"))
-            print("\n\n", method_bytes)
+            self.logger.info("\n\n", method_bytes)
             self.lib.nd_method_exit(bt, ctypes.c_char_p(method_bytes))
 
     def method_exit(self, bt, method, status=200, duration=0):
@@ -332,7 +334,7 @@ class Agent(object):
     def start_business_transaction_native(self, bt_name, correlation_header):
         if os.environ['nd_init_done'] == '0':
             self.start()
-            print("start_business_transaction ->")
+            self.logger.info("start_business_transaction ->")
             self.logger.debug(" start_business_transaction -> lib.obj {0}:".format(self.lib))
             # btname = bytes(bt_name, 'utf-8')
             # self.logger.info("btname type and value: {0} and {1}".format(type(btname), btname))
@@ -360,11 +362,11 @@ class Agent(object):
 
         bt = self.lib.nd_bt_begin(bt_name_c, correlation_header_c)
         #self.logger.info("bt datatype : {0}".format(type(bt)))
-        print("btname value: {0}".format(btname))
+        self.logger.info("btname value: {0}".format(btname))
         # print('-----------------\nCurrent heap memory stack for BT: ',bt_name,' is : ',hpy().heap())
         self.active_bts.add(bt)
         self.set_current_bt(bt)
-        print("BT value of this txn: ", bt)
+        self.logger.info("BT value of this txn: {}".format(bt))
         return bt
 
     def start_business_transaction(self, bt_name, correlation_header):
@@ -391,14 +393,14 @@ class Agent(object):
             self.havoc_monitor.apply_inbound_service_delay(bt_name)
         except Exception as e:
             # Will fail first time
-            print(e)
+            self.logger.info("{}".format(e))
             pass
 
         return bt
 
     # @profile
     def end_business_transaction_native(self, bt):
-        print("end_business_transaction--> BT: ", bt)
+        self.logger.info("end_business_transaction--> BT: {}".format(bt))
         self.logger.info('end_business_transaction--> lib variable in end txn: {0}'.format(self.lib))
         self.logger.info('At end_business_transaction bt value is {0}'.format(bt))
         statuscode = self.get_current_status_code()
@@ -539,10 +541,10 @@ class Agent(object):
 
 
     def wait_for_end(self, timeout_ms=None):
-        """Wait for the agent to finish reporting any pending BTs.
+        """Wait for the printagent to finish reporting any pending BTs.
 
         """
-        self.tx_svc.wait_for_end(timeout_ms=timeout_ms)
+        self.tx_svc.waitprint_for_end(timeout_ms=timeout_ms)
 
     #@property
     def enabled(self):
@@ -551,7 +553,7 @@ class Agent(object):
             """
             return (
                     self.nd_init_done and
-                    self.config_svc and self.config_svc.enabled and
+                    selfprint.config_svc and self.config_svc.enabled and
                     self.tx_svc)
 
     def get_current_bt(self):
