@@ -9,7 +9,7 @@ import subprocess
 import uuid
 import datetime
 
-is_lambda = True 
+is_lambda = True
 
 if is_lambda:
     os.environ.setdefault("ND_HOME", "/opt/python/pythonagent/cavisson/netdiagnostics")
@@ -27,16 +27,13 @@ logger = None
 try:
     import pythonagent.agent as agent
     agent.configure()
-    #_agent = agent.bootstrap()
     _agent = agent.get_agent_instance()
-    #_agent.init_sent = True
 
-except:
-    print("import error in Agent")
     logger = logging.getLogger('pythonagent.agent')
-    logger.exception('Exception in agent startup.')
-finally:
-    pass
+    logger.error("Cavisson PythonAgent Initialized")
+
+except Exception as e:
+    logger.exception("Exception in agent startup {}".format(e))
 
 if _agent is None:
     raise ValueError("Failed to initialize agent")
@@ -47,29 +44,22 @@ from pythonagent.agent.internal.agent import TransactionContext
 
 
 def get_handler():
-    print("inside get_handler function first", sys.executable)
+    logger.info("inside get_handler function first {}".format(sys.executable))
     modandpackage = os.path.abspath('.')
     mod = sys.modules[__name__]
-    print("inside get_handler function mod", mod)
+
+    logger.info("inside get_handler function {}".format(mod))
     try:
         sys.path.remove(os.path.dirname(__file__))
     except ValueError:  # directory not in sys.path
         pass
 
-
-    if (
-            "CAVISSON_LAMBDA_HANDLER" not in os.environ
-            or not os.environ["CAVISSON_LAMBDA_HANDLER"]
-    ):
-        raise ValueError(
-            "No value specified in CAVISSON_LAMBDA_HANDLER environment variable"
-        )
+    if "CAVISSON_LAMBDA_HANDLER" not in os.environ or not os.environ["CAVISSON_LAMBDA_HANDLER"]:
+        raise ValueError("No value specified in CAVISSON_LAMBDA_HANDLER environment variable")
 
     try:
-        module_path, handler_name = os.environ["CAVISSON_LAMBDA_HANDLER"].rsplit(
-            ".", 1
-        )
-        print("inside get_handler function module_path, handler name: ", module_path, handler_name)
+        module_path, handler_name = os.environ["CAVISSON_LAMBDA_HANDLER"].rsplit(".", 1)
+        logger.info("inside get_handler function module_path {} handler name {}:".format(module_path,handler_name))
 
     except ValueError:
         raise ValueError(
@@ -93,14 +83,13 @@ def get_handler():
                     "Cannot use built-in module %s as a handler module" % module_path
                 )
 
-        print("inside get_handler function module_path, file_handle, pathname, desc", module_path, file_handle, pathname, desc)
-
+        logger.info("inside get_handler function module_path {}, file_handle {}, pathname {}, desc {}".format(module_path, file_handle, pathname, desc))
         module = imp.load_module(module_path, file_handle, pathname, desc)
-        print("inside get_handler function module in cavagent_lambda_wrapper ", module)
+        logger.info("inside get_handler function module {} in cavagent_lambda_wrapper".format(module))
         
 
     except Exception as e:
-        print("Module not found")
+        logger.error("Module not found")
         raise ImportError("Failed to import module '%s': %s" % (module_path, e))
     finally:
         if file_handle is not None:
@@ -108,9 +97,9 @@ def get_handler():
 
     try:
         handler = getattr(module, handler_name)
-        print("inside get_handler function handler", handler)
+        logger.info("inside get_handler function handler {}".format(handler))
     except AttributeError:
-        print("NO HANDLER FOUND")
+        logger.info("NO HANDLER FOUND")
         raise AttributeError(
             "No handler '%s' in module '%s'" % (handler_name, module_path)
         )
@@ -120,13 +109,13 @@ def get_handler():
 
 def local_customer_application(event, context):
     from .run import db_callout, flask_wsgi, http_callout, first
-    print("inside local_customer_application function Lambda Handler Function")
+    logger.info("inside local_customer_application function Lambda Handler Function")
 
-    #first()
+    first()
     # second()
     # http_callout()
     # db_callout()
-    flask_wsgi()
+    # flask_wsgi()
 
     return "Nothing"
 
@@ -165,7 +154,8 @@ def handler(event, context):
         context_obj.function_name = context.function_name
     else:
         context_obj.function_name = "default"
-    print("function name inside context object in cavwrapper handler", context_obj.function_name)
+
+    logger.info("function name inside context object in cavwrapper handler {}".format(context_obj.function_name))
 
 
     try:
@@ -194,27 +184,19 @@ def handler(event, context):
 
     try:
         bt = _agent.start_business_transaction(context_obj.url_path, "")
+        logger.error("Cavisson PythonAgent Business transation started")
     except Exception as e:
-        print("Error occurred in Start Business transaction Call {}".format(e))
+        logger.error("Error occurred in Start Business transaction Call {}".format(e))
 
-    # import time
-    # print("Start fp done, sleep 30")
-    # time.sleep(30)
 
     try:
         handle, handler_name, modandpackage = wrapped_handler(event, context, is_lambda)
     except Exception as e:
-        print("Error occurred in Calling Wrapped Handler {}".format(e))
+        logger.error("Error occurred in Calling Wrapped Handler {}".format(e))
 
 
-    print("inside handler function handle, handler_name, modandpackage IN CAVAGENT_LAMBDA_WRAPPER", handle, handler_name, modandpackage)
+    logger.info("inside handler function handle {}, handler_name {}, modandpackage {} IN CAVAGENT_LAMBDA_WRAPPER".format(handle, handler_name, modandpackage))
     #fqmmethodentry = str(modandpackage) + "." + str(handler_name)
-
-    print("handle", handle)
-
-    print("\n\n")
-
-
     fqmmethodentry = str(handle.__module__) + "." + str(handler_name)
 
     _agent.method_entry(bt, fqmmethodentry)
@@ -222,9 +204,9 @@ def handler(event, context):
     if is_lambda:
         try:
             response = handle(event, context)  # Client Lambda Function
-            print("inside handler function RESPONSE IN LAMBDA IN CAVAGENT_LAMBDA_WRAPPER", response)
+            logger.info("inside handler function RESPONSE IN LAMBDA IN CAVAGENT_LAMBDA_WRAPPER response {}".format(response))
         except Exception as e:
-            print("Error while invoking handler {}".format(e))
+            logger.error("Error while invoking handler {}".format(e))
             _agent.method_exit(bt, fqmmethodentry, 503)
             _agent.set_current_status_code(503)
             rc = _agent.end_business_transaction(bt)
@@ -232,17 +214,17 @@ def handler(event, context):
             raise e
     else:
         response = local_customer_application(event, context)
-        print("inside handler function RESPONSE IN LAMBDA IN CAVAGENT_LAMBDA_WRAPPER", response)
+        logger.info("inside handler function RESPONSE IN LAMBDA IN CAVAGENT_LAMBDA_WRAPPER response {}".format(response))
 
     status_code = 200
     try:
         if "statusCode" in response:
             status_code = response["statusCode"]
 
-        print("Inside handler function: response inside get_handler function firststatus code ", status_code)
+        logger.info("Inside handler function: response inside get_handler function first status code {}".format(status_code))
 
     except Exception as e:
-        print("Error occurred in get status code {}".format(e))
+        logger.error("Error occurred in get status code {}".format(e))
 
 
 
@@ -255,28 +237,28 @@ def handler(event, context):
     # Apply Inbound Failure
 
     try:
-        print("Url request: ", context_obj.url_path)
+        logger.debug("Url request: {} ".format(context_obj.url_path))
         havoc_monitor.apply_inbound_service_failure(context_obj.url_path)
 
     except Exception as e:
         if isinstance(e, NDHavocException):
-            print("Havoc Exception {}".format(e))
+            logger.error("Havoc Exception {}".format(e))
             _agent.method_exit(bt, fqmmethodentry, 503)
             _agent.set_current_status_code(503)
             rc = _agent.end_business_transaction(bt)
+            logger.error("Cavisson PythonAgent Business Transaction ended")
             havoc_monitor.refresh_configs(_agent)
             raise e
         else:
-            print("Non-Havoc Exception {}".format(e))
+            logger.error("Non-Havoc Exception {}".format(e))
 
-    # Apply Outbound Delay --> agent/method_entry_http_callout
 
-    # Apply Outbound Failure --> agent/probes/base.py/http_call_end
-    #                        --> agent/probes/sql/dynamodb.py/_cav_boto_api_method
-
-    # Apply Method Delay --> Instrumentation/__init__
-
-    # Apply Method Failure --> Instrumentation/__init__
+###############################FOR UNDERSTANDING HAVOC ISSUES##############################
+    """Apply Outbound Delay --> agent/method_entry_http_callout
+    Apply Outbound Failure --> agent/probes/base.py/http_call_end
+                           --> agent/probes/sql/dynamodb.py/_cav_boto_api_method
+    Apply Method Delay --> Instrumentation/__init__
+    Apply Method Failure --> Instrumentation/__init__"""
 
     ####################################################################################
 
@@ -290,10 +272,6 @@ def handler(event, context):
         rc = _agent.end_business_transaction(bt)
 
     except Exception as e:
-        print("Error occurred in End Business transaction Call {}".format(e))
+        logger.error("Error occurred in End Business transaction Call {}".format(e))
 
     return response
-
-
-
-
